@@ -110,6 +110,10 @@ run_config:
             # Optional annotations to apply on pods
             #annotations:
               #iam.amazonaws.com/role: airflow
+              #vault.hashicorp.com/agent-inject-template-foo: |
+              # {{- with secret "database/creds/db-app" -}}
+              # postgres://{{ .Data.username }}:{{ .Data.password }}@postgres:5432/mydb
+              # {{- end }}
             # Optional list of kubernetes tolerations
             #tolerations:
                 #- key: "group"
@@ -345,6 +349,10 @@ class SparkConfig(Config):
     def user_init_path(self):
         return self._get_or_default("user_init_path", None)
 
+    @property
+    def user_post_init_path(self):
+        return self._get_or_default("user_post_init_path", None)
+
     @property
     def cluster_config(self):
         return self._get_or_default("cluster_config", {})
